#!/bin/bash

if test $# -lt 1; then
    echo 1>&2 "Usage: $0 log_file1 [log_file2 ...]"
    exit 1
fi

trap "/bin/rm -f *.tmp-$$" 0 1 2 3 15

order=0
for f in "$@"; do
    g=${f%.log}
    if ! test -r "$f"; then
	echo 1>&2 "Cannot read file \"$f\", abort."
	exit 1
    fi
    echo 1>&2 "Creating \"$g.tmp-$$\"."
    awk '/DOF/ {n=$2} /Error/ {print n, $4}' "$f" >"$g.tmp-$$"
    order=`awk '/DOF type:/ {print $3}' "$f" | sed -e 's/[^0-9]//g'`
done

(
    cat <<END
	set style data lines
	set logscale xy
	set grid
	set xrange [$rang0:$range1]
	set xlabel "Degrees of freedom"
	set ylabel "Error estimate"
	set output "plot.eps"
	set term postscript eps color 18
	set pointsize 2
END
    prefix='	plot'
    for f in "$@"; do
	g=${f%.log}
	t1=`echo $g | awk -F- '{print $1}'`
	t2=`echo $g | awk -F- '{print $2}'`
	test -n "$t2" && t2=" ($t2)"
	echo -n "${prefix} \"$g.tmp-$$\" title \"$t1 refinement$t2\""
	prefix=', \
	    '
    done
    x0=`head -1 "$g.tmp-$$" | awk '{print $1}'`
    y0=`head -1 "$g.tmp-$$" | awk '{print $2}' | sed -e 's/,//g'`
    echo "$prefix $y0*(($x0/x)**($order/3.))" \
	 "title \"a line with slope -$order/3\""
) | gnuplot


/bin/rm -f *.tmp-$$

# Change linewidth and add cmdline
sed -i  -e "s/gnulinewidth 5/gnulinewidth 15/g" \
	-e "s|\\(^%%Creator: .*\\)$|\\1\\n%%CreationCommand: $0 $*|" plot.eps
echo 1>&2 "Creating \"plot.eps\"."
